@@ -66,7 +66,7 @@ class Load(Event, bubble=False):
 class Idle(Event, bubble=False):
     """Sent when there are no more items in the message queue.
 
-    This is a psuedo-event in that it is created by the Textual system and doesn't go
+    This is a pseudo-event in that it is created by the Textual system and doesn't go
     through the usual message queue.
 
     """
@@ -237,7 +237,7 @@ class MouseEvent(InputEvent, bubble=True):
         Args:
             sender (MessageTarget): The sender of the event.
             x (int): The relative x coordinate.
-            y (int): The relative y cootdinate.
+            y (int): The relative y coordinate.
             delta_x (int): Change in x since the last message.
             delta_y (int): Change in y since the last message.
             button (int): Indexed of the pressed button.
@@ -333,7 +333,7 @@ class MouseUp(MouseEvent, bubble=True):
     pass
 
 
-class MouseScrollDown(InputEvent, bubble=True):
+class MouseScrollDown(InputEvent, verbosity=3, bubble=True):
     __slots__ = ["x", "y"]
 
     def __init__(self, sender: MessageTarget, x: int, y: int) -> None:
